@@ -356,10 +356,10 @@ class readSam(object):
             read_name_r1 = line_r1[0]
             read_name_r2 = line_r2[0]
             if read_name_r1 != read_name_r2:
-                print(read_name_r1)
-                print(read_name_r2)
+                self._mut_log.info(read_name_r1)
+                self._mut_log.info(read_name_r2)
                 self._mut_log.error("Read pair IDs did not map, please check fastq files")
-                exit(1)
+                raise  ValueError("Read pair IDs did not map, please check fastq files")
 
             # get starting position for r1 and r2
             pos_start_r1 = line_r1[3]
